@@ -1,5 +1,3 @@
-package Bot::BasicBot::Pluggable::Module::Gitbot;
-
 use MooseX::Declare;
 
 class Bot::BasicBot::Pluggable::Module::Gitbot
@@ -159,11 +157,11 @@ Bot::BasicBot::Pluggable::Module::Gitbot - A Bot::BasicBot::Pluggable Module to
 
 =head1 VERSION
 
-Version 0.01
+Version 0.01.02
 
 =cut
 
-our $VERSION = '0.01.01';
+our $VERSION = '0.01.02';
 
 =head1 SYNOPSIS
 
